==> pact_matching_ffi-0.0.4.crate: pact_matching_ffi-0.0.4/CHANGELOG.md <==
To generate the log, run `git log --pretty='* %h - %s (%an, %ad)' TAGNAME..HEAD .` replacing TAGNAME and HEAD as appropriate.

# 0.0.4 - support accumulating log entries per running mock server

* 6d058529 - chore: fix some clippy warnings (Ronald Holshausen, Mon May 31 16:42:57 2021 +1000)
* 70d18a28 - chore: clippy violation (Ronald Holshausen, Mon May 31 15:32:32 2021 +1000)
* 17beef62 - feat: support accumulating log entries per running mock server (Ronald Holshausen, Mon May 31 15:09:20 2021 +1000)
* a5bad95f - bump version to 0.0.4 (Ronald Holshausen, Sun May 30 17:28:37 2021 +1000)

# 0.0.3 - FFI mockserver to log to a memory buffer

* f0dc803 - chore: fix clippy voilation (Ronald Holshausen, Sun May 30 17:09:24 2021 +1000)
* 02b8bc3 - chore: run the C example after the pact_matching_ffi examples (Ronald Holshausen, Sun May 30 16:51:27 2021 +1000)
* 90ff271 - chore: correct markdown doc example (Ronald Holshausen, Sun May 30 16:30:25 2021 +1000)
* eb19188 - feat: allow FFI mockserver to log to a memory buffer (Ronald Holshausen, Sun May 30 15:31:01 2021 +1000)
* 142e625 - bump version to 0.0.3 (Ronald Holshausen, Sun May 30 11:00:24 2021 +1000)

# 0.0.2 - Refactor: Moved provider state models

* 7022625 - refactor: move provider state models to the pact models crate (Ronald Holshausen, Sat May 29 17:18:48 2021 +1000)

# 0.0.1 - First Release

* fc81f3e - chore: prep for release (Ronald Holshausen, Tue May 4 10:24:18 2021 +1000)
* cf38771 - chore: only run cmake build on Linux agents (Ronald Holshausen, Tue May 4 09:06:06 2021 +1000)
* 57c1549 - chore: fix ci build (Ronald Holshausen, Mon May 3 16:43:09 2021 +1000)
* 4ada5e9 - chore: fix ci build (Ronald Holshausen, Mon May 3 16:30:29 2021 +1000)
* e06d11b - chore: run cbingen because cmake is not running it (Ronald Holshausen, Mon May 3 16:19:22 2021 +1000)
* 163859e - chore: debugging build (Ronald Holshausen, Mon May 3 15:51:33 2021 +1000)
* 78ad9c6 - chore: fix ci build script (Ronald Holshausen, Mon May 3 15:22:39 2021 +1000)
* 7534d85 - chore: compile debug on CI (Ronald Holshausen, Mon May 3 15:12:39 2021 +1000)
* b3d52b3 - chore: correct the dyn lib name for OSX (Ronald Holshausen, Mon May 3 15:11:39 2021 +1000)
* b4d09a5 - chore: only use nightly rust for the cbindgen command (Ronald Holshausen, Mon May 3 14:45:49 2021 +1000)
* 4593d58 - chore: debug CI build (Ronald Holshausen, Mon May 3 14:20:07 2021 +1000)
* adfd783 - chore: link to the shared lib on Linux and OSX (Ronald Holshausen, Mon May 3 14:02:09 2021 +1000)
* 91f244a - chore: debug CI build (Ronald Holshausen, Mon May 3 13:39:35 2021 +1000)
* f1ed340 - chore: update examples to link to pthread dl m on Linux (Ronald Holshausen, Mon May 3 11:10:54 2021 +1000)
* a95129b - chore: include pact_models in cbindgen config (Ronald Holshausen, Mon May 3 10:54:31 2021 +1000)
* f04dc70 - chore(pact_matching_ffi): fix for CMake error with set_target_properties (Ronald Holshausen, Mon Apr 26 09:11:51 2021 +1000)
* 3fb9d92 - chore: cd out of build dir before trying to run the examples (Ronald Holshausen, Sun Apr 25 17:21:54 2021 +1000)
* 320ff87 - chore: cargo manfest was missing staticlib; CMake install had the wrong output file name (Ronald Holshausen, Sun Apr 25 17:03:45 2021 +1000)
* 2714994 - chore(pact_matching_ffi): doxygen not available on CI OSX and Windows (Ronald Holshausen, Sun Apr 25 15:54:01 2021 +1000)
* 2d0edf2 - Revert "chore(pact_matching_ffi): Update CMake config to execute nightly cargo" (Ronald Holshausen, Sun Apr 25 15:33:06 2021 +1000)
* 43fb55a - chore(pact_matching_ffi): Update CMake config to execute nightly cargo (Ronald Holshausen, Sun Apr 25 15:26:04 2021 +1000)
* 84d3c42 - chore(pact_matching_ffi): use the correct directory in CI (Ronald Holshausen, Sun Apr 25 14:56:09 2021 +1000)
* 5028f91 - chore: add CI build for pact_matching_ffi (Ronald Holshausen, Sun Apr 25 14:43:11 2021 +1000)
* 735c9e7 - chore: bump pact_matching to 0.9 (Ronald Holshausen, Sun Apr 25 13:50:18 2021 +1000)
* fb373b4 - chore: bump version to 0.0.2 (Ronald Holshausen, Sun Apr 25 13:40:52 2021 +1000)
* 3dd610a - refactor: move structs and code dealing with bodies to a seperate package (Ronald Holshausen, Sun Apr 25 11:20:47 2021 +1000)
* 80b7148 - feat(V4): Updated consumer DSL to set comments + mock server initial support for V4 pacts (Ronald Holshausen, Fri Apr 23 17:58:10 2021 +1000)
* 75b2928 - Resolved Clippy lints (Andrew Lilley Brinker, Thu Apr 22 14:21:06 2021 -0700)
* 44c7b3c - Updated to compile with latest changes (Andrew Lilley Brinker, Thu Apr 22 13:40:17 2021 -0700)
* bd02e36 - Upstream prep (#79) (Andrew Lilley Brinker, Thu Apr 22 09:49:05 2021 -0700)
* a07e76a - Added message iterator for message pacts (#76) (Andrew Lilley Brinker, Wed Mar 24 13:15:58 2021 -0700)
* 6f8e186 - Added provider_state_delete function (#60) (Andrew Lilley Brinker, Tue Feb 23 09:53:13 2021 -0800)
* fd55c67 - Added message_new_from_body (#61) (Andrew Lilley Brinker, Tue Feb 23 09:52:58 2021 -0800)
* 104782e - Added logic to detect when not using Cargo nightly (#56) (Andrew Lilley Brinker, Tue Feb 2 10:16:12 2021 -0800)
* 06b0e79 - Use absolute paths in macros for hygiene (#53) (Caleb Stepanian, Thu Dec 24 23:05:47 2020 -0500)
* 851d623 - Resolve some warnings during CMake build. (#52) (Andrew Lilley Brinker, Tue Dec 22 10:38:59 2020 -0800)
* d110ecd - Update cbindgen config (#51) (Andrew Lilley Brinker, Wed Dec 9 13:41:25 2020 -0800)
* 09bafa7 - First pass at basic matching with the FFI. (#50) (Andrew Lilley Brinker, Fri Dec 4 13:56:40 2020 -0800)
* 5e15927 - Add my name to the crate author list (#49) (Caleb Stepanian, Thu Nov 5 13:22:59 2020 -0500)
* b2f2799 - Updated pact_matching version in ffi (Andrew Lilley Brinker, Wed Nov 4 09:53:26 2020 -0800)
* 4c937f2 - Added metadata iteration for message pacts (#48) (Andrew Lilley Brinker, Fri Oct 30 18:18:09 2020 -0700)
* 4c3f75d - Message pact metadata (#46) (Andrew Lilley Brinker, Thu Oct 29 14:29:42 2020 -0700)
* 9b4f05b - Add FFI methods to get consumer and provider from MessagePact (#47) (Caleb Stepanian, Mon Oct 26 21:43:03 2020 -0400)
* 9e30378 - Change cbindgen config (#45) (Andrew Lilley Brinker, Thu Oct 22 12:48:57 2020 -0700)
* 41347af - Add FFI wrappers for constructing and deleting MessagePact (#43) (Caleb Stepanian, Wed Oct 14 14:00:02 2020 -0400)
* 6c709fe - Fix CMake build failure by renaming 'FFI' -> 'Ffi' (#33) (Caleb Stepanian, Tue Oct 6 10:03:35 2020 -0400)
* 2375013 - Bump pact_matching dependency version (#32) (Andrew Lilley Brinker, Mon Oct 5 06:48:13 2020 -0700)
* f247a23 - Fix Doxygen Output (#30) (Andrew Lilley Brinker, Fri Sep 11 07:53:43 2020 -0700)
* 4510dbb - Adding README.md with build instructions using CMake (#31) (Andrew Lilley Brinker, Fri Sep 11 07:42:56 2020 -0700)
* a99c7b0 - Add support for reading Message provider states (#29) (Andrew Lilley Brinker, Wed Sep 2 10:26:55 2020 -0700)
* 7a339fa - Added metadata key/value iteration (#28) (Andrew Lilley Brinker, Thu Aug 6 13:37:06 2020 -0700)
* 44700c8 - Message style improvements (#26) (#27) (Andrew Lilley Brinker, Thu Jul 30 10:55:35 2020 -0700)
* f6cddcc - Configured CMake to run Doxygen on FFI header file (#25) (Andrew Lilley Brinker, Fri Jun 26 09:01:43 2020 -0700)
* af31f17 - Bump pact_matching version in FFI (#24) (Andrew Lilley Brinker, Thu Jun 25 11:30:42 2020 -0700)
* a35e5d3 - Add additional FFI Message APIs (Caleb Stepanian, Wed Jun 24 11:23:24 2020 -0700)
* 7d6c101 - Add cmake and an example (#23) (Andrew Lilley Brinker, Mon Jun 22 06:29:28 2020 -0700)
* 6405181 - Added basic FFI for Pact Messages (Andrew Lilley Brinker, Fri Apr 17 12:52:27 2020 -0700)
* b57a970 - Establish pact_matching_ffi logging mechanism (Andrew Lilley Brinker, Thu Apr 16 13:36:53 2020 -0700)
* eac17cf - Added error handling / reporting, and other basic utilities. (#8) (Andrew Lilley Brinker, Thu Apr 16 11:09:17 2020 -0700)
* c2c64d2 - Added empty pact_matching_ffi crate to workspace (Andrew Lilley Brinker, Wed Apr 15 13:45:46 2020 -0700)

# 0.0.0 - Initial Release

==> pact_matching_ffi-0.0.5.crate: pact_matching_ffi-0.0.5/CHANGELOG.md <==
To generate the log, run `git log --pretty='* %h - %s (%an, %ad)' TAGNAME..HEAD .` replacing TAGNAME and HEAD as appropriate.

# 0.0.5 - Deprecated Library

* 8e1136ec - chore: add deprecation notes to the FFI crates (Ronald Holshausen, Wed Jul 7 13:44:23 2021 +1000)
* 48475166 - chore: add deprecation notes to the FFI libs (Ronald Holshausen, Wed Jul 7 12:43:42 2021 +1000)
* 33f9a823 - feat: support complex data structures in message metadata (Matt Fellows, Mon Jul 5 23:38:52 2021 +1000)
* 05620d7a - bump version to 0.0.5 (Ronald Holshausen, Wed Jun 23 13:52:32 2021 +1000)

# 0.0.4 - support accumulating log entries per running mock server

* 6d058529 - chore: fix some clippy warnings (Ronald Holshausen, Mon May 31 16:42:57 2021 +1000)
* 70d18a28 - chore: clippy violation (Ronald Holshausen, Mon May 31 15:32:32 2021 +1000)
* 17beef62 - feat: support accumulating log entries per running mock server (Ronald Holshausen, Mon May 31 15:09:20 2021 +1000)
* a5bad95f - bump version to 0.0.4 (Ronald Holshausen, Sun May 30 17:28:37 2021 +1000)

# 0.0.3 - FFI mockserver to log to a memory buffer

* f0dc803 - chore: fix clippy voilation (Ronald Holshausen, Sun May 30 17:09:24 2021 +1000)
* 02b8bc3 - chore: run the C example after the pact_matching_ffi examples (Ronald Holshausen, Sun May 30 16:51:27 2021 +1000)
* 90ff271 - chore: correct markdown doc example (Ronald Holshausen, Sun May 30 16:30:25 2021 +1000)
* eb19188 - feat: allow FFI mockserver to log to a memory buffer (Ronald Holshausen, Sun May 30 15:31:01 2021 +1000)
* 142e625 - bump version to 0.0.3 (Ronald Holshausen, Sun May 30 11:00:24 2021 +1000)

# 0.0.2 - Refactor: Moved provider state models

* 7022625 - refactor: move provider state models to the pact models crate (Ronald Holshausen, Sat May 29 17:18:48 2021 +1000)

# 0.0.1 - First Release

* fc81f3e - chore: prep for release (Ronald Holshausen, Tue May 4 10:24:18 2021 +1000)
* cf38771 - chore: only run cmake build on Linux agents (Ronald Holshausen, Tue May 4 09:06:06 2021 +1000)
* 57c1549 - chore: fix ci build (Ronald Holshausen, Mon May 3 16:43:09 2021 +1000)
* 4ada5e9 - chore: fix ci build (Ronald Holshausen, Mon May 3 16:30:29 2021 +1000)
* e06d11b - chore: run cbingen because cmake is not running it (Ronald Holshausen, Mon May 3 16:19:22 2021 +1000)
* 163859e - chore: debugging build (Ronald Holshausen, Mon May 3 15:51:33 2021 +1000)
* 78ad9c6 - chore: fix ci build script (Ronald Holshausen, Mon May 3 15:22:39 2021 +1000)
* 7534d85 - chore: compile debug on CI (Ronald Holshausen, Mon May 3 15:12:39 2021 +1000)
* b3d52b3 - chore: correct the dyn lib name for OSX (Ronald Holshausen, Mon May 3 15:11:39 2021 +1000)
* b4d09a5 - chore: only use nightly rust for the cbindgen command (Ronald Holshausen, Mon May 3 14:45:49 2021 +1000)
* 4593d58 - chore: debug CI build (Ronald Holshausen, Mon May 3 14:20:07 2021 +1000)
* adfd783 - chore: link to the shared lib on Linux and OSX (Ronald Holshausen, Mon May 3 14:02:09 2021 +1000)
* 91f244a - chore: debug CI build (Ronald Holshausen, Mon May 3 13:39:35 2021 +1000)
* f1ed340 - chore: update examples to link to pthread dl m on Linux (Ronald Holshausen, Mon May 3 11:10:54 2021 +1000)
* a95129b - chore: include pact_models in cbindgen config (Ronald Holshausen, Mon May 3 10:54:31 2021 +1000)
* f04dc70 - chore(pact_matching_ffi): fix for CMake error with set_target_properties (Ronald Holshausen, Mon Apr 26 09:11:51 2021 +1000)
* 3fb9d92 - chore: cd out of build dir before trying to run the examples (Ronald Holshausen, Sun Apr 25 17:21:54 2021 +1000)
* 320ff87 - chore: cargo manfest was missing staticlib; CMake install had the wrong output file name (Ronald Holshausen, Sun Apr 25 17:03:45 2021 +1000)
* 2714994 - chore(pact_matching_ffi): doxygen not available on CI OSX and Windows (Ronald Holshausen, Sun Apr 25 15:54:01 2021 +1000)
* 2d0edf2 - Revert "chore(pact_matching_ffi): Update CMake config to execute nightly cargo" (Ronald Holshausen, Sun Apr 25 15:33:06 2021 +1000)
* 43fb55a - chore(pact_matching_ffi): Update CMake config to execute nightly cargo (Ronald Holshausen, Sun Apr 25 15:26:04 2021 +1000)
* 84d3c42 - chore(pact_matching_ffi): use the correct directory in CI (Ronald Holshausen, Sun Apr 25 14:56:09 2021 +1000)
* 5028f91 - chore: add CI build for pact_matching_ffi (Ronald Holshausen, Sun Apr 25 14:43:11 2021 +1000)
* 735c9e7 - chore: bump pact_matching to 0.9 (Ronald Holshausen, Sun Apr 25 13:50:18 2021 +1000)
* fb373b4 - chore: bump version to 0.0.2 (Ronald Holshausen, Sun Apr 25 13:40:52 2021 +1000)
* 3dd610a - refactor: move structs and code dealing with bodies to a seperate package (Ronald Holshausen, Sun Apr 25 11:20:47 2021 +1000)
* 80b7148 - feat(V4): Updated consumer DSL to set comments + mock server initial support for V4 pacts (Ronald Holshausen, Fri Apr 23 17:58:10 2021 +1000)
* 75b2928 - Resolved Clippy lints (Andrew Lilley Brinker, Thu Apr 22 14:21:06 2021 -0700)
* 44c7b3c - Updated to compile with latest changes (Andrew Lilley Brinker, Thu Apr 22 13:40:17 2021 -0700)
* bd02e36 - Upstream prep (#79) (Andrew Lilley Brinker, Thu Apr 22 09:49:05 2021 -0700)
* a07e76a - Added message iterator for message pacts (#76) (Andrew Lilley Brinker, Wed Mar 24 13:15:58 2021 -0700)
* 6f8e186 - Added provider_state_delete function (#60) (Andrew Lilley Brinker, Tue Feb 23 09:53:13 2021 -0800)
* fd55c67 - Added message_new_from_body (#61) (Andrew Lilley Brinker, Tue Feb 23 09:52:58 2021 -0800)
* 104782e - Added logic to detect when not using Cargo nightly (#56) (Andrew Lilley Brinker, Tue Feb 2 10:16:12 2021 -0800)
* 06b0e79 - Use absolute paths in macros for hygiene (#53) (Caleb Stepanian, Thu Dec 24 23:05:47 2020 -0500)
* 851d623 - Resolve some warnings during CMake build. (#52) (Andrew Lilley Brinker, Tue Dec 22 10:38:59 2020 -0800)
* d110ecd - Update cbindgen config (#51) (Andrew Lilley Brinker, Wed Dec 9 13:41:25 2020 -0800)
* 09bafa7 - First pass at basic matching with the FFI. (#50) (Andrew Lilley Brinker, Fri Dec 4 13:56:40 2020 -0800)
* 5e15927 - Add my name to the crate author list (#49) (Caleb Stepanian, Thu Nov 5 13:22:59 2020 -0500)
* b2f2799 - Updated pact_matching version in ffi (Andrew Lilley Brinker, Wed Nov 4 09:53:26 2020 -0800)
* 4c937f2 - Added metadata iteration for message pacts (#48) (Andrew Lilley Brinker, Fri Oct 30 18:18:09 2020 -0700)
* 4c3f75d - Message pact metadata (#46) (Andrew Lilley Brinker, Thu Oct 29 14:29:42 2020 -0700)
* 9b4f05b - Add FFI methods to get consumer and provider from MessagePact (#47) (Caleb Stepanian, Mon Oct 26 21:43:03 2020 -0400)
* 9e30378 - Change cbindgen config (#45) (Andrew Lilley Brinker, Thu Oct 22 12:48:57 2020 -0700)
* 41347af - Add FFI wrappers for constructing and deleting MessagePact (#43) (Caleb Stepanian, Wed Oct 14 14:00:02 2020 -0400)
* 6c709fe - Fix CMake build failure by renaming 'FFI' -> 'Ffi' (#33) (Caleb Stepanian, Tue Oct 6 10:03:35 2020 -0400)
* 2375013 - Bump pact_matching dependency version (#32) (Andrew Lilley Brinker, Mon Oct 5 06:48:13 2020 -0700)
* f247a23 - Fix Doxygen Output (#30) (Andrew Lilley Brinker, Fri Sep 11 07:53:43 2020 -0700)
* 4510dbb - Adding README.md with build instructions using CMake (#31) (Andrew Lilley Brinker, Fri Sep 11 07:42:56 2020 -0700)
* a99c7b0 - Add support for reading Message provider states (#29) (Andrew Lilley Brinker, Wed Sep 2 10:26:55 2020 -0700)
* 7a339fa - Added metadata key/value iteration (#28) (Andrew Lilley Brinker, Thu Aug 6 13:37:06 2020 -0700)
* 44700c8 - Message style improvements (#26) (#27) (Andrew Lilley Brinker, Thu Jul 30 10:55:35 2020 -0700)
* f6cddcc - Configured CMake to run Doxygen on FFI header file (#25) (Andrew Lilley Brinker, Fri Jun 26 09:01:43 2020 -0700)
* af31f17 - Bump pact_matching version in FFI (#24) (Andrew Lilley Brinker, Thu Jun 25 11:30:42 2020 -0700)
* a35e5d3 - Add additional FFI Message APIs (Caleb Stepanian, Wed Jun 24 11:23:24 2020 -0700)
* 7d6c101 - Add cmake and an example (#23) (Andrew Lilley Brinker, Mon Jun 22 06:29:28 2020 -0700)
* 6405181 - Added basic FFI for Pact Messages (Andrew Lilley Brinker, Fri Apr 17 12:52:27 2020 -0700)
* b57a970 - Establish pact_matching_ffi logging mechanism (Andrew Lilley Brinker, Thu Apr 16 13:36:53 2020 -0700)
* eac17cf - Added error handling / reporting, and other basic utilities. (#8) (Andrew Lilley Brinker, Thu Apr 16 11:09:17 2020 -0700)
* c2c64d2 - Added empty pact_matching_ffi crate to workspace (Andrew Lilley Brinker, Wed Apr 15 13:45:46 2020 -0700)

# 0.0.0 - Initial Release
